@@ -29,15 +29,15 @@
 #include <QObject>
 
 #include "depth_cloud_display.h"
-#include "rviz/visualization_manager.h"
-#include "rviz/properties/property.h"
-#include "rviz/validate_floats.h"
+#include <rviz/visualization_manager.h>
+#include <rviz/properties/property.h>
+#include <rviz/validate_floats.h>
 
-#include "rviz/properties/enum_property.h"
-#include "rviz/properties/float_property.h"
-#include "rviz/properties/bool_property.h"
-#include "rviz/properties/int_property.h"
-#include "rviz/frame_manager.h"
+#include <rviz/properties/enum_property.h>
+#include <rviz/properties/float_property.h>
+#include <rviz/properties/bool_property.h>
+#include <rviz/properties/int_property.h>
+#include <rviz/frame_manager.h>
 
 #include <tf2_ros/buffer.h>
 
@@ -65,7 +65,6 @@ namespace enc = sensor_msgs::image_encodings;
 
 namespace rviz
 {
-
 DepthCloudDisplay::DepthCloudDisplay()
   : rviz::Display()
   , messages_received_(0)
@@ -78,28 +77,25 @@ DepthCloudDisplay::DepthCloudDisplay()
   , trans_thres_(0.01f)
 
 {
-
   // Depth map properties
   QRegExp depth_filter("depth");
   depth_filter.setCaseSensitivity(Qt::CaseInsensitive);
 
-  topic_filter_property_ = new Property("Topic Filter",
-                                        true,
-                                        "List only topics with names that relate to depth and color images",
-                                        this,
-                                        SLOT (updateTopicFilter() ));
+  topic_filter_property_ =
+      new Property("Topic Filter", true,
+                   "List only topics with names that relate to depth and color images", this,
+                   SLOT(updateTopicFilter()));
 
-  depth_topic_property_ = new RosFilteredTopicProperty("Depth Map Topic",
-                                                       "",
-                                                       QString::fromStdString(ros::message_traits::datatype<sensor_msgs::Image>()),
-                                                       "sensor_msgs::Image topic to subscribe to.",
-                                                       depth_filter,
-                                                       this,
-                                                       SLOT( updateTopic() ));
+  depth_topic_property_ = new RosFilteredTopicProperty(
+      "Depth Map Topic", "", QString::fromStdString(ros::message_traits::datatype<sensor_msgs::Image>()),
+      "sensor_msgs::Image topic to subscribe to.", depth_filter, this, SLOT(updateTopic()));
 
-  depth_transport_property_ = new EnumProperty("Depth Map Transport Hint", "raw", "Preferred method of sending images.", this, SLOT( updateTopic() ));
+  depth_transport_property_ =
+      new EnumProperty("Depth Map Transport Hint", "raw", "Preferred method of sending images.", this,
+                       SLOT(updateTopic()));
 
-  connect(depth_transport_property_, SIGNAL( requestOptions( EnumProperty* )), this,  SLOT( fillTransportOptionList( EnumProperty* )));
+  connect(depth_transport_property_, SIGNAL(requestOptions(EnumProperty*)), this,
+          SLOT(fillTransportOptionList(EnumProperty*)));
 
   depth_transport_property_->setStdString("raw");
 
@@ -107,64 +103,55 @@ DepthCloudDisplay::DepthCloudDisplay()
   QRegExp color_filter("color|rgb|bgr|gray|mono");
   color_filter.setCaseSensitivity(Qt::CaseInsensitive);
 
-  color_topic_property_ = new RosFilteredTopicProperty("Color Image Topic",
-                                                       "",
-                                                       QString::fromStdString(ros::message_traits::datatype<sensor_msgs::Image>()),
-                                                       "sensor_msgs::Image topic to subscribe to.",
-                                                       color_filter,
-                                                       this,
-                                                       SLOT( updateTopic() ));
+  color_topic_property_ = new RosFilteredTopicProperty(
+      "Color Image Topic", "",
+      QString::fromStdString(ros::message_traits::datatype<sensor_msgs::Image>()),
+      "sensor_msgs::Image topic to subscribe to.", color_filter, this, SLOT(updateTopic()));
 
-  color_transport_property_ = new EnumProperty("Color Transport Hint", "raw", "Preferred method of sending images.", this, SLOT( updateTopic() ));
+  color_transport_property_ = new EnumProperty(
+      "Color Transport Hint", "raw", "Preferred method of sending images.", this, SLOT(updateTopic()));
 
 
-  connect(color_transport_property_, SIGNAL( requestOptions( EnumProperty* )), this, SLOT( fillTransportOptionList( EnumProperty* )));
+  connect(color_transport_property_, SIGNAL(requestOptions(EnumProperty*)), this,
+          SLOT(fillTransportOptionList(EnumProperty*)));
 
   color_transport_property_->setStdString("raw");
 
   // Queue size property
-  queue_size_property_ = new IntProperty( "Queue Size", queue_size_,
-                                          "Advanced: set the size of the incoming message queue.  Increasing this "
-                                          "is useful if your incoming TF data is delayed significantly from your"
-                                          " image data, but it can greatly increase memory usage if the messages are big.",
-                                          this,
-                                          SLOT( updateQueueSize() ));
-  queue_size_property_->setMin( 1 );
+  queue_size_property_ =
+      new IntProperty("Queue Size", queue_size_,
+                      "Advanced: set the size of the incoming message queue.  Increasing this "
+                      "is useful if your incoming TF data is delayed significantly from your"
+                      " image data, but it can greatly increase memory usage if the messages are big.",
+                      this, SLOT(updateQueueSize()));
+  queue_size_property_->setMin(1);
 
-  use_auto_size_property_ = new BoolProperty( "Auto Size",
-                                              true,
-                                              "Automatically scale each point based on its depth value and the camera parameters.",
-                                              this,
-                                              SLOT( updateUseAutoSize() ),
-                                              this );
+  use_auto_size_property_ = new BoolProperty(
+      "Auto Size", true,
+      "Automatically scale each point based on its depth value and the camera parameters.", this,
+      SLOT(updateUseAutoSize()), this);
 
-  auto_size_factor_property_ = new FloatProperty( "Auto Size Factor", 1,
-                                                  "Scaling factor to be applied to the auto size.",
-                                                  use_auto_size_property_,
-                                                  SLOT( updateAutoSizeFactor() ),
-                                                  this );
-  auto_size_factor_property_->setMin( 0.0001 );
+  auto_size_factor_property_ =
+      new FloatProperty("Auto Size Factor", 1, "Scaling factor to be applied to the auto size.",
+                        use_auto_size_property_, SLOT(updateAutoSizeFactor()), this);
+  auto_size_factor_property_->setMin(0.0001);
 
-  use_occlusion_compensation_property_ = new BoolProperty( "Occlusion Compensation",
-                                                           false,
-                                                           "Keep points alive after they have been occluded by a closer point. Points are removed after a timeout or when the camera frame moves.",
-                                                           this,
-                                                           SLOT( updateUseOcclusionCompensation() ),
-                                                           this );
-
-  occlusion_shadow_timeout_property_ = new FloatProperty( "Occlusion Time-Out",
-                                                          30.0f,
-                                                          "Amount of seconds before removing occluded points from the depth cloud",
-                                                          use_occlusion_compensation_property_,
-                                                          SLOT( updateOcclusionTimeOut() ),
-                                                          this );
+  use_occlusion_compensation_property_ =
+      new BoolProperty("Occlusion Compensation", false,
+                       "Keep points alive after they have been occluded by a closer point. Points are "
+                       "removed after a timeout or when the camera frame moves.",
+                       this, SLOT(updateUseOcclusionCompensation()), this);
 
+  occlusion_shadow_timeout_property_ =
+      new FloatProperty("Occlusion Time-Out", 30.0f,
+                        "Amount of seconds before removing occluded points from the depth cloud",
+                        use_occlusion_compensation_property_, SLOT(updateOcclusionTimeOut()), this);
 }
 
 void DepthCloudDisplay::onInitialize()
 {
-  depthmap_it_.reset( new image_transport::ImageTransport( threaded_nh_ ));
-  rgb_it_.reset( new image_transport::ImageTransport( threaded_nh_ ));
+  depthmap_it_.reset(new image_transport::ImageTransport(threaded_nh_));
+  rgb_it_.reset(new image_transport::ImageTransport(threaded_nh_));
 
   // Instantiate PointCloudCommon class for displaying point clouds
   pointcloud_common_ = new PointCloudCommon(this);
@@ -174,7 +161,7 @@ void DepthCloudDisplay::onInitialize()
 
   // PointCloudCommon sets up a callback queue with a thread for each
   // instance.  Use that for processing incoming messages.
-  threaded_nh_.setCallbackQueue( pointcloud_common_->getCallbackQueue() );
+  threaded_nh_.setCallbackQueue(pointcloud_common_->getCallbackQueue());
 
   // Scan for available transport plugins
   scanForTransportSubscriberPlugins();
@@ -185,7 +172,7 @@ void DepthCloudDisplay::onInitialize()
 
 DepthCloudDisplay::~DepthCloudDisplay()
 {
-  if ( initialized() )
+  if (initialized())
   {
     unsubscribe();
     delete pointcloud_common_;
@@ -197,28 +184,27 @@ DepthCloudDisplay::~DepthCloudDisplay()
   }
 }
 
-void DepthCloudDisplay::setTopic( const QString &topic, const QString &datatype )
+void DepthCloudDisplay::setTopic(const QString& topic, const QString& datatype)
 {
   // Copied from ImageDisplayBase::setTopic()
-  if ( datatype == ros::message_traits::datatype<sensor_msgs::Image>() )
+  if (datatype == ros::message_traits::datatype<sensor_msgs::Image>())
   {
-    depth_transport_property_->setStdString( "raw" );
-    depth_topic_property_->setString( topic );
+    depth_transport_property_->setStdString("raw");
+    depth_topic_property_->setString(topic);
   }
   else
   {
     int index = topic.lastIndexOf("/");
-    if ( index == -1 )
+    if (index == -1)
     {
-      ROS_WARN("DepthCloudDisplay::setTopic() Invalid topic name: %s",
-               topic.toStdString().c_str());
+      ROS_WARN("DepthCloudDisplay::setTopic() Invalid topic name: %s", topic.toStdString().c_str());
       return;
     }
     QString transport = topic.mid(index + 1);
     QString base_topic = topic.mid(0, index);
 
-    depth_transport_property_->setString( transport );
-    depth_topic_property_->setString( base_topic );
+    depth_transport_property_->setString(transport);
+    depth_topic_property_->setString(base_topic);
   }
 }
 
@@ -230,11 +216,11 @@ void DepthCloudDisplay::updateQueueSize()
 void DepthCloudDisplay::updateUseAutoSize()
 {
   bool use_auto_size = use_auto_size_property_->getBool();
-  pointcloud_common_->point_world_size_property_->setReadOnly( use_auto_size );
-  pointcloud_common_->setAutoSize( use_auto_size );
+  pointcloud_common_->point_world_size_property_->setReadOnly(use_auto_size);
+  pointcloud_common_->setAutoSize(use_auto_size);
   auto_size_factor_property_->setHidden(!use_auto_size);
   if (use_auto_size)
-	  use_auto_size_property_->expand();
+    use_auto_size_property_->expand();
 }
 
 void DepthCloudDisplay::updateAutoSizeFactor()
@@ -258,7 +244,8 @@ void DepthCloudDisplay::updateUseOcclusionCompensation()
     updateOcclusionTimeOut();
     ml_depth_data_->enableOcclusionCompensation(true);
     use_occlusion_compensation_property_->expand();
-  } else
+  }
+  else
   {
     ml_depth_data_->enableOcclusionCompensation(false);
   }
@@ -286,7 +273,7 @@ void DepthCloudDisplay::onDisable()
 
 void DepthCloudDisplay::subscribe()
 {
-  if ( !isEnabled() )
+  if (!isEnabled())
   {
     return;
   }
@@ -306,56 +293,57 @@ void DepthCloudDisplay::subscribe()
     std::string depthmap_transport = depth_transport_property_->getStdString();
     std::string color_transport = color_transport_property_->getStdString();
 
-    if (!depthmap_topic.empty() && !depthmap_transport.empty()) {
+    if (!depthmap_topic.empty() && !depthmap_transport.empty())
+    {
       // subscribe to depth map topic
-      depthmap_sub_->subscribe(*depthmap_it_, depthmap_topic, queue_size_,  image_transport::TransportHints(depthmap_transport));
+      depthmap_sub_->subscribe(*depthmap_it_, depthmap_topic, queue_size_,
+                               image_transport::TransportHints(depthmap_transport));
 
       depthmap_tf_filter_.reset(new tf2_ros::MessageFilter<sensor_msgs::Image>(
-        *depthmap_sub_,
-        *context_->getTF2BufferPtr(),
-        fixed_frame_.toStdString(),
-        queue_size_,
-        threaded_nh_
-      ));
+          *depthmap_sub_, *context_->getTF2BufferPtr(), fixed_frame_.toStdString(), queue_size_,
+          threaded_nh_));
 
       // subscribe to CameraInfo  topic
       std::string info_topic = image_transport::getCameraInfoTopic(depthmap_topic);
       cam_info_sub_->subscribe(threaded_nh_, info_topic, queue_size_);
       cam_info_sub_->registerCallback(boost::bind(&DepthCloudDisplay::caminfoCallback, this, _1));
 
-      if (!color_topic.empty() && !color_transport.empty()) {
+      if (!color_topic.empty() && !color_transport.empty())
+      {
         // subscribe to color image topic
-        rgb_sub_->subscribe(*rgb_it_, color_topic, queue_size_,  image_transport::TransportHints(color_transport));
+        rgb_sub_->subscribe(*rgb_it_, color_topic, queue_size_,
+                            image_transport::TransportHints(color_transport));
 
         // connect message filters to synchronizer
         sync_depth_color_->connectInput(*depthmap_tf_filter_, *rgb_sub_);
         sync_depth_color_->setInterMessageLowerBound(0, ros::Duration(0.5));
         sync_depth_color_->setInterMessageLowerBound(1, ros::Duration(0.5));
-        sync_depth_color_->registerCallback(boost::bind(&DepthCloudDisplay::processMessage, this, _1, _2));
+        sync_depth_color_->registerCallback(
+            boost::bind(&DepthCloudDisplay::processMessage, this, _1, _2));
 
         pointcloud_common_->color_transformer_property_->setValue("RGB8");
-      } else
+      }
+      else
       {
         depthmap_tf_filter_->registerCallback(boost::bind(&DepthCloudDisplay::processMessage, this, _1));
       }
-
     }
   }
   catch (ros::Exception& e)
   {
-    setStatus( StatusProperty::Error, "Message", QString("Error subscribing: ") + e.what() );
+    setStatus(StatusProperty::Error, "Message", QString("Error subscribing: ") + e.what());
   }
   catch (image_transport::TransportLoadException& e)
   {
-    setStatus( StatusProperty::Error, "Message", QString("Error subscribing: ") + e.what() );
+    setStatus(StatusProperty::Error, "Message", QString("Error subscribing: ") + e.what());
   }
 }
 
-void DepthCloudDisplay::caminfoCallback( sensor_msgs::CameraInfo::ConstPtr msg )
+void DepthCloudDisplay::caminfoCallback(sensor_msgs::CameraInfo::ConstPtr msg)
 {
   boost::mutex::scoped_lock lock(cam_info_mutex_);
-  cam_info_ = msg;
- }
+  cam_info_ = std::move(msg);
+}
 
 void DepthCloudDisplay::unsubscribe()
 {
@@ -372,14 +360,13 @@ void DepthCloudDisplay::unsubscribe()
   }
   catch (ros::Exception& e)
   {
-    setStatus( StatusProperty::Error, "Message", QString("Error unsubscribing: ") + e.what() );
+    setStatus(StatusProperty::Error, "Message", QString("Error unsubscribing: ") + e.what());
   }
 }
 
 
 void DepthCloudDisplay::clear()
 {
-
   boost::mutex::scoped_lock lock(mutex_);
 
   pointcloud_common_->reset();
@@ -388,7 +375,6 @@ void DepthCloudDisplay::clear()
 
 void DepthCloudDisplay::update(float wall_dt, float ros_dt)
 {
-
   boost::mutex::scoped_lock lock(mutex_);
 
   pointcloud_common_->update(wall_dt, ros_dt);
@@ -399,19 +385,19 @@ void DepthCloudDisplay::reset()
 {
   clear();
   messages_received_ = 0;
-  setStatus( StatusProperty::Ok, "Depth Map", "0 depth maps received" );
-  setStatus( StatusProperty::Ok, "Message", "Ok" );
+  setStatus(StatusProperty::Ok, "Depth Map", "0 depth maps received");
+  setStatus(StatusProperty::Ok, "Message", "Ok");
 }
 
-void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg)
+void DepthCloudDisplay::processMessage(const sensor_msgs::ImageConstPtr& depth_msg)
 {
   processMessage(depth_msg, sensor_msgs::ImageConstPtr());
 }
 
-void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
-                                       sensor_msgs::ImageConstPtr rgb_msg)
+void DepthCloudDisplay::processMessage(const sensor_msgs::ImageConstPtr& depth_msg,
+                                       const sensor_msgs::ImageConstPtr& rgb_msg)
 {
-  if (context_->getFrameManager()->getPause() )
+  if (context_->getFrameManager()->getPause())
   {
     return;
   }
@@ -419,8 +405,9 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
   std::ostringstream s;
 
   ++messages_received_;
-  setStatus( StatusProperty::Ok, "Depth Map", QString::number(messages_received_) + " depth maps received");
-  setStatus( StatusProperty::Ok, "Message", "Ok" );
+  setStatus(StatusProperty::Ok, "Depth Map",
+            QString::number(messages_received_) + " depth maps received");
+  setStatus(StatusProperty::Ok, "Message", "Ok");
 
   sensor_msgs::CameraInfo::ConstPtr cam_info;
   {
@@ -428,36 +415,36 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
     cam_info = cam_info_;
   }
 
-  if ( !cam_info || !depth_msg )
+  if (!cam_info || !depth_msg)
   {
     return;
   }
 
   s.str("");
   s << depth_msg->width << " x " << depth_msg->height;
-  setStatusStd( StatusProperty::Ok, "Depth Image Size", s.str() );
+  setStatusStd(StatusProperty::Ok, "Depth Image Size", s.str());
 
   if (rgb_msg)
   {
     s.str("");
     s << rgb_msg->width << " x " << rgb_msg->height;
-    setStatusStd( StatusProperty::Ok, "Image Size", s.str() );
+    setStatusStd(StatusProperty::Ok, "Image Size", s.str());
 
     if (depth_msg->header.frame_id != rgb_msg->header.frame_id)
     {
       std::stringstream errorMsg;
       errorMsg << "Depth image frame id [" << depth_msg->header.frame_id.c_str()
-           << "] doesn't match color image frame id [" << rgb_msg->header.frame_id.c_str() << "]";
-      setStatusStd( StatusProperty::Warn, "Message", errorMsg.str() );
+               << "] doesn't match color image frame id [" << rgb_msg->header.frame_id.c_str() << "]";
+      setStatusStd(StatusProperty::Warn, "Message", errorMsg.str());
     }
   }
 
-  if ( use_auto_size_property_->getBool() )
+  if (use_auto_size_property_->getBool())
   {
     float f = cam_info->K[0];
     float bx = cam_info->binning_x > 0 ? cam_info->binning_x : 1.0;
     float s = auto_size_factor_property_->getFloat();
-    pointcloud_common_->point_world_size_property_->setFloat( s / f * bx );
+    pointcloud_common_->point_world_size_property_->setFloat(s / f * bx);
   }
 
   bool use_occlusion_compensation = use_occlusion_compensation_property_->getBool();
@@ -470,11 +457,10 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
 
     if (!context_->getFrameManager()->getTransform(depth_msg->header, position, orientation))
     {
-      setStatus(
-          StatusProperty::Error,
-          "Message",
-          QString("Failed to transform from frame [") + depth_msg->header.frame_id.c_str() + QString("] to frame [")
-              + context_->getFrameManager()->getFixedFrame().c_str() + QString("]"));
+      setStatus(StatusProperty::Error, "Message",
+                QString("Failed to transform from frame [") + depth_msg->header.frame_id.c_str() +
+                    QString("] to frame [") + context_->getFrameManager()->getFixedFrame().c_str() +
+                    QString("]"));
       return;
     }
     else
@@ -491,8 +477,7 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
         angle_deg += 180.0f;
 
       if (trans_thres_ == 0.0 || angular_thres_ == 0.0 ||
-          (position - current_position_).length() > trans_thres_
-          || angle_deg > angular_thres_)
+          (position - current_position_).length() > trans_thres_ || angle_deg > angular_thres_)
       {
         // camera orientation/position changed
         current_position_ = position;
@@ -506,9 +491,10 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
 
   try
   {
-    sensor_msgs::PointCloud2Ptr cloud_msg = ml_depth_data_->generatePointCloudFromDepth(depth_msg, rgb_msg, cam_info);
+    sensor_msgs::PointCloud2Ptr cloud_msg =
+        ml_depth_data_->generatePointCloudFromDepth(depth_msg, rgb_msg, cam_info);
 
-    if ( !cloud_msg.get() )
+    if (!cloud_msg.get())
     {
       throw MultiLayerDepthException("generatePointCloudFromDepth() returned zero.");
     }
@@ -521,18 +507,15 @@ void DepthCloudDisplay::processMessage(sensor_msgs::ImageConstPtr depth_msg,
   {
     setStatus(StatusProperty::Error, "Message", QString("Error updating depth cloud: ") + e.what());
   }
-
-
-
 }
 
 
 void DepthCloudDisplay::scanForTransportSubscriberPlugins()
 {
-  pluginlib::ClassLoader<image_transport::SubscriberPlugin> sub_loader("image_transport",
-                                                                       "image_transport::SubscriberPlugin");
+  pluginlib::ClassLoader<image_transport::SubscriberPlugin> sub_loader(
+      "image_transport", "image_transport::SubscriberPlugin");
 
-  BOOST_FOREACH( const std::string& lookup_name, sub_loader.getDeclaredClasses() )
+  BOOST_FOREACH (const std::string& lookup_name, sub_loader.getDeclaredClasses())
   {
     // lookup_name is formatted as "pkg/transport_sub", for instance
     // "image_transport/compressed_sub" for the "compressed"
@@ -591,8 +574,8 @@ void DepthCloudDisplay::fillTransportOptionList(EnumProperty* property)
     const std::string& topic_name = ti.name;
     const std::string& topic = depth_topic_property_->getStdString();
 
-    if (topic_name.find(topic) == 0 && topic_name != topic && topic_name[topic.size()] == '/'
-        && topic_name.find('/', topic.size() + 1) == std::string::npos)
+    if (topic_name.find(topic) == 0 && topic_name != topic && topic_name[topic.size()] == '/' &&
+        topic_name.find('/', topic.size() + 1) == std::string::npos)
     {
       std::string transport_type = topic_name.substr(topic.size() + 1);
 
@@ -619,6 +602,7 @@ void DepthCloudDisplay::fixedFrameChanged()
 } // namespace rviz
 
 #include <pluginlib/class_list_macros.hpp>
+#include <utility>
 
-PLUGINLIB_EXPORT_CLASS( rviz::DepthCloudDisplay, rviz::Display)
 
+PLUGINLIB_EXPORT_CLASS(rviz::DepthCloudDisplay, rviz::Display)
