@@ -28,59 +28,93 @@
  */
 
 #include "marker_utils.h"
-#include "rviz/default_plugin/markers/shape_marker.h"
-#include "rviz/default_plugin/markers/arrow_marker.h"
-#include "rviz/default_plugin/markers/line_list_marker.h"
-#include "rviz/default_plugin/markers/line_strip_marker.h"
-#include "rviz/default_plugin/marker_display.h"
-#include "rviz/default_plugin/markers/points_marker.h"
-#include "rviz/default_plugin/markers/text_view_facing_marker.h"
-#include "rviz/default_plugin/markers/mesh_resource_marker.h"
-#include "rviz/default_plugin/markers/triangle_list_marker.h"
-#include "rviz/display_context.h"
-#include "rviz/properties/property.h"
-#include "rviz/properties/property_tree_model.h"
-#include "rviz/properties/status_property.h"
-#include "rviz/properties/status_list.h"
-#include "rviz/validate_quaternions.h"
-#include "rviz/validate_floats.h"
+#include <rviz/default_plugin/markers/shape_marker.h>
+#include <rviz/default_plugin/markers/arrow_marker.h>
+#include <rviz/default_plugin/markers/line_list_marker.h>
+#include <rviz/default_plugin/markers/line_strip_marker.h>
+#include <rviz/default_plugin/marker_display.h>
+#include <rviz/default_plugin/markers/points_marker.h>
+#include <rviz/default_plugin/markers/text_view_facing_marker.h>
+#include <rviz/default_plugin/markers/mesh_resource_marker.h>
+#include <rviz/default_plugin/markers/triangle_list_marker.h>
+#include <rviz/display_context.h>
+#include <rviz/properties/property.h>
+#include <rviz/properties/property_tree_model.h>
+#include <rviz/properties/status_property.h>
+#include <rviz/properties/status_list.h>
+#include <rviz/validate_quaternions.h>
+#include <rviz/validate_floats.h>
 
 namespace rviz
 {
-
-MarkerBase* createMarker(int marker_type, MarkerDisplay* owner, DisplayContext* context, Ogre::SceneNode* parent_node)
+MarkerBase*
+createMarker(int marker_type, MarkerDisplay* owner, DisplayContext* context, Ogre::SceneNode* parent_node)
 {
-  switch (marker_type) {
+  switch (marker_type)
+  {
   case visualization_msgs::Marker::CUBE:
   case visualization_msgs::Marker::CYLINDER:
   case visualization_msgs::Marker::SPHERE:
-     return new rviz::ShapeMarker(owner, context, parent_node);
+    return new rviz::ShapeMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::ARROW:
-     return new rviz::ArrowMarker(owner, context, parent_node);
+    return new rviz::ArrowMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::LINE_STRIP:
-     return new rviz::LineStripMarker(owner, context, parent_node);
+    return new rviz::LineStripMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::LINE_LIST:
-     return new rviz::LineListMarker(owner, context, parent_node);
+    return new rviz::LineListMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::SPHERE_LIST:
   case visualization_msgs::Marker::CUBE_LIST:
   case visualization_msgs::Marker::POINTS:
-     return new rviz::PointsMarker(owner, context, parent_node);
+    return new rviz::PointsMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::TEXT_VIEW_FACING:
-     return new rviz::TextViewFacingMarker(owner, context, parent_node);
+    return new rviz::TextViewFacingMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::MESH_RESOURCE:
-     return new rviz::MeshResourceMarker(owner, context, parent_node);
+    return new rviz::MeshResourceMarker(owner, context, parent_node);
 
   case visualization_msgs::Marker::TRIANGLE_LIST:
-     return new rviz::TriangleListMarker(owner, context, parent_node);
+    return new rviz::TriangleListMarker(owner, context, parent_node);
 
   default:
-     return nullptr;
+    return nullptr;
+  }
+}
+
+QString getMarkerTypeName(unsigned int type)
+{
+  switch (type)
+  {
+  case visualization_msgs::Marker::ARROW:
+    return "Arrow";
+  case visualization_msgs::Marker::CUBE:
+    return "Cube";
+  case visualization_msgs::Marker::CUBE_LIST:
+    return "Cube List";
+  case visualization_msgs::Marker::TRIANGLE_LIST:
+    return "Triangle List";
+  case visualization_msgs::Marker::SPHERE:
+    return "Sphere";
+  case visualization_msgs::Marker::SPHERE_LIST:
+    return "Sphere List";
+  case visualization_msgs::Marker::CYLINDER:
+    return "Cylinder";
+  case visualization_msgs::Marker::LINE_STRIP:
+    return "Line Strip";
+  case visualization_msgs::Marker::LINE_LIST:
+    return "Line List";
+  case visualization_msgs::Marker::POINTS:
+    return "Points";
+  case visualization_msgs::Marker::TEXT_VIEW_FACING:
+    return "Text View Facing";
+  case visualization_msgs::Marker::MESH_RESOURCE:
+    return "Mesh";
+  default:
+    return "Unknown";
   }
 }
 
@@ -94,22 +128,35 @@ void addSeparatorIfRequired(std::stringstream& ss)
   }
 }
 
-void increaseLevel(::ros::console::levels::Level new_status, ::ros::console::levels::Level& current_status)
+void increaseLevel(::ros::console::levels::Level new_status,
+                   ::ros::console::levels::Level& current_status)
 {
-  if(new_status > current_status)
+  if (new_status > current_status)
     current_status = new_status;
 }
 
 template <typename T>
 constexpr const char* fieldName();
 template <>
-constexpr const char* fieldName<::geometry_msgs::Point>() { return "Position"; }
+constexpr const char* fieldName<::geometry_msgs::Point>()
+{
+  return "Position";
+}
 template <>
-constexpr const char* fieldName<::geometry_msgs::Quaternion>() { return "Orientation"; }
+constexpr const char* fieldName<::geometry_msgs::Quaternion>()
+{
+  return "Orientation";
+}
 template <>
-constexpr const char* fieldName<::geometry_msgs::Vector3>() { return "Scale"; }
+constexpr const char* fieldName<::geometry_msgs::Vector3>()
+{
+  return "Scale";
+}
 template <>
-constexpr const char* fieldName<::std_msgs::ColorRGBA>() { return "Color"; }
+constexpr const char* fieldName<::std_msgs::ColorRGBA>()
+{
+  return "Color";
+}
 
 template <typename T>
 void checkFloats(const T& t, std::stringstream& ss, ::ros::console::levels::Level& level)
@@ -122,17 +169,19 @@ void checkFloats(const T& t, std::stringstream& ss, ::ros::console::levels::Leve
   }
 }
 
-void checkQuaternion(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkQuaternion(const visualization_msgs::Marker& marker,
+                     std::stringstream& ss,
+                     ::ros::console::levels::Level& level)
 {
   checkFloats(marker.pose.orientation, ss, level);
-  if (marker.pose.orientation.x == 0.0 && marker.pose.orientation.y == 0.0 && marker.pose.orientation.z == 0.0 &&
-      marker.pose.orientation.w == 0.0)
+  if (marker.pose.orientation.x == 0.0 && marker.pose.orientation.y == 0.0 &&
+      marker.pose.orientation.z == 0.0 && marker.pose.orientation.w == 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "Uninitialized quaternion, assuming identity.";
     increaseLevel(::ros::console::levels::Info, level);
   }
-  else if(!validateQuaternions(marker.pose))
+  else if (!validateQuaternions(marker.pose))
   {
     addSeparatorIfRequired(ss);
     ss << "Unnormalized quaternion in marker message.";
@@ -140,14 +189,16 @@ void checkQuaternion(const visualization_msgs::Marker& marker, std::stringstream
   }
 }
 
-void checkScale(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkScale(const visualization_msgs::Marker& marker,
+                std::stringstream& ss,
+                ::ros::console::levels::Level& level)
 {
   checkFloats(marker.scale, ss, level);
   // for ARROW markers, scale.z is the optional head length
-  if(marker.type == visualization_msgs::Marker::ARROW && marker.scale.x != 0.0 && marker.scale.y != 0.0)
+  if (marker.type == visualization_msgs::Marker::ARROW && marker.scale.x != 0.0 && marker.scale.y != 0.0)
     return;
 
-  if(marker.scale.x == 0.0  || marker.scale.y == 0.0  || marker.scale.z == 0.0)
+  if (marker.scale.x == 0.0 || marker.scale.y == 0.0 || marker.scale.z == 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "Scale contains 0.0 in x, y or z.";
@@ -155,15 +206,17 @@ void checkScale(const visualization_msgs::Marker& marker, std::stringstream& ss,
   }
 }
 
-void checkScaleLineStripAndList(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkScaleLineStripAndList(const visualization_msgs::Marker& marker,
+                                std::stringstream& ss,
+                                ::ros::console::levels::Level& level)
 {
-  if(marker.scale.x == 0.0)
+  if (marker.scale.x == 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "Width LINE_LIST or LINE_STRIP is 0.0 (scale.x).";
     increaseLevel(::ros::console::levels::Warn, level);
   }
-  else if(marker.scale.y != 0.0 || marker.scale.z != 0.0)
+  else if (marker.scale.y != 0.0 || marker.scale.z != 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "scale.y and scale.z of LINE_LIST or LINE_STRIP are ignored.";
@@ -171,15 +224,17 @@ void checkScaleLineStripAndList(const visualization_msgs::Marker& marker, std::s
   }
 }
 
-void checkScalePoints(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkScalePoints(const visualization_msgs::Marker& marker,
+                      std::stringstream& ss,
+                      ::ros::console::levels::Level& level)
 {
-  if(marker.scale.x == 0.0 || marker.scale.y == 0.0)
+  if (marker.scale.x == 0.0 || marker.scale.y == 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "Width and/or height of POINTS is 0.0 (scale.x, scale.y).";
     increaseLevel(::ros::console::levels::Warn, level);
   }
-  else if(marker.scale.z != 0.0)
+  else if (marker.scale.z != 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "scale.z of POINTS is ignored.";
@@ -187,15 +242,17 @@ void checkScalePoints(const visualization_msgs::Marker& marker, std::stringstrea
   }
 }
 
-void checkScaleText(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkScaleText(const visualization_msgs::Marker& marker,
+                    std::stringstream& ss,
+                    ::ros::console::levels::Level& level)
 {
-  if(marker.scale.z == 0.0)
+  if (marker.scale.z == 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "Text height of TEXT_VIEW_FACING is 0.0 (scale.z).";
     increaseLevel(::ros::console::levels::Warn, level);
   }
-  else if(marker.scale.x != 0.0 || marker.scale.y != 0.0)
+  else if (marker.scale.x != 0.0 || marker.scale.y != 0.0)
   {
     addSeparatorIfRequired(ss);
     ss << "scale.x and scale.y of TEXT_VIEW_FACING are ignored.";
@@ -203,13 +260,16 @@ void checkScaleText(const visualization_msgs::Marker& marker, std::stringstream&
   }
 }
 
-void checkColor(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkColor(const visualization_msgs::Marker& marker,
+                std::stringstream& ss,
+                ::ros::console::levels::Level& level)
 {
   checkFloats(marker.color, ss, level);
-  if(marker.color.a == 0.0 &&
-     // Mesh markers use a color of (0,0,0,0) to indicate that the original color of the mesh should be used as is
-     !(marker.type == visualization_msgs::Marker::MESH_RESOURCE && marker.mesh_use_embedded_materials
-       && marker.color.r == 0.0 && marker.color.g == 0.0 && marker.color.b == 0.0))
+  if (marker.color.a == 0.0 &&
+      // Mesh markers use a color of (0,0,0,0) to indicate that the original color of the mesh should be
+      // used as is
+      !(marker.type == visualization_msgs::Marker::MESH_RESOURCE && marker.mesh_use_embedded_materials &&
+        marker.color.r == 0.0 && marker.color.g == 0.0 && marker.color.b == 0.0))
   {
     addSeparatorIfRequired(ss);
     ss << "Marker is fully transparent (color.a is 0.0).";
@@ -217,19 +277,26 @@ void checkColor(const visualization_msgs::Marker& marker, std::stringstream& ss,
   }
 }
 
-void checkPointsArrow(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkPointsArrow(const visualization_msgs::Marker& marker,
+                      std::stringstream& ss,
+                      ::ros::console::levels::Level& level)
 {
-  if(marker.points.size() != 0 && marker.points.size() != 2)
+  if (!marker.points.empty() && marker.points.size() != 2)
   {
     addSeparatorIfRequired(ss);
     ss << "Number of points for an ARROW marker should be either 0 or 2.";
     increaseLevel(::ros::console::levels::Error, level);
+    return;
   }
+  for (const auto& p : marker.points)
+    checkFloats(p, ss, level);
 }
 
-void checkPointsNotEmpty(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkPointsNotEmpty(const visualization_msgs::Marker& marker,
+                         std::stringstream& ss,
+                         ::ros::console::levels::Level& level)
 {
-  if(marker.points.empty())
+  if (marker.points.empty())
   {
     addSeparatorIfRequired(ss);
     ss << "Points should not be empty for specified marker type.";
@@ -237,38 +304,40 @@ void checkPointsNotEmpty(const visualization_msgs::Marker& marker, std::stringst
   }
   switch (marker.type)
   {
-    case visualization_msgs::Marker::TRIANGLE_LIST:
-      if (marker.points.size() % 3 != 0)
-      {
-        addSeparatorIfRequired(ss);
-        ss << "Number of points should be a multiple of 3 for TRIANGLE_LIST marker.";
-        increaseLevel(::ros::console::levels::Error, level);
-      }
-      break;
-    case visualization_msgs::Marker::LINE_LIST:
-      if (marker.points.size() % 2 != 0)
-      {
-        addSeparatorIfRequired(ss);
-        ss << "Number of points should be a multiple of 2 for LINE_LIST marker.";
-        increaseLevel(::ros::console::levels::Error, level);
-      }
-      break;
-    case visualization_msgs::Marker::LINE_STRIP:
-      if (marker.points.size() <= 1)
-      {
-        addSeparatorIfRequired(ss);
-        ss << "At least two points are required for a LINE_STRIP marker.";
-        increaseLevel(::ros::console::levels::Error, level);
-      }
-      break;
-    default:
-      break;
+  case visualization_msgs::Marker::TRIANGLE_LIST:
+    if (marker.points.size() % 3 != 0)
+    {
+      addSeparatorIfRequired(ss);
+      ss << "Number of points should be a multiple of 3 for TRIANGLE_LIST marker.";
+      increaseLevel(::ros::console::levels::Error, level);
+    }
+    break;
+  case visualization_msgs::Marker::LINE_LIST:
+    if (marker.points.size() % 2 != 0)
+    {
+      addSeparatorIfRequired(ss);
+      ss << "Number of points should be a multiple of 2 for LINE_LIST marker.";
+      increaseLevel(::ros::console::levels::Error, level);
+    }
+    break;
+  case visualization_msgs::Marker::LINE_STRIP:
+    if (marker.points.size() <= 1)
+    {
+      addSeparatorIfRequired(ss);
+      ss << "At least two points are required for a LINE_STRIP marker.";
+      increaseLevel(::ros::console::levels::Error, level);
+    }
+    break;
+  default:
+    break;
   }
 }
 
-void checkPointsEmpty(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkPointsEmpty(const visualization_msgs::Marker& marker,
+                      std::stringstream& ss,
+                      ::ros::console::levels::Level& level)
 {
-  if(!marker.points.empty())
+  if (!marker.points.empty())
   {
     addSeparatorIfRequired(ss);
     ss << "Non-empty points array is ignored.";
@@ -276,14 +345,18 @@ void checkPointsEmpty(const visualization_msgs::Marker& marker, std::stringstrea
   }
 }
 
-void checkColors(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level, unsigned int multiple)
+void checkColors(const visualization_msgs::Marker& marker,
+                 std::stringstream& ss,
+                 ::ros::console::levels::Level& level,
+                 unsigned int multiple)
 {
-  if(marker.colors.size() == 0)
+  if (marker.colors.empty())
   {
     checkColor(marker, ss, level);
     return;
   }
-  if(marker.colors.size() != marker.points.size() && (multiple == 1 || multiple * marker.colors.size() != marker.points.size()))
+  if (marker.colors.size() != marker.points.size() &&
+      (multiple == 1 || multiple * marker.colors.size() != marker.points.size()))
   {
     addSeparatorIfRequired(ss);
     ss << "Number of colors doesn't match number of points.";
@@ -291,9 +364,11 @@ void checkColors(const visualization_msgs::Marker& marker, std::stringstream& ss
   }
 }
 
-void checkColorsEmpty(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkColorsEmpty(const visualization_msgs::Marker& marker,
+                      std::stringstream& ss,
+                      ::ros::console::levels::Level& level)
 {
-  if(!marker.colors.empty())
+  if (!marker.colors.empty())
   {
     addSeparatorIfRequired(ss);
     ss << "Non-empty colors array is ignored.";
@@ -301,9 +376,11 @@ void checkColorsEmpty(const visualization_msgs::Marker& marker, std::stringstrea
   }
 }
 
-void checkTextNotEmptyOrWhitespace(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkTextNotEmptyOrWhitespace(const visualization_msgs::Marker& marker,
+                                   std::stringstream& ss,
+                                   ::ros::console::levels::Level& level)
 {
-  if(marker.text.find_first_not_of(" \t\n\v\f\r") == std::string::npos)
+  if (marker.text.find_first_not_of(" \t\n\v\f\r") == std::string::npos)
   {
     addSeparatorIfRequired(ss);
     ss << "Text is empty or only consists of whitespace.";
@@ -311,9 +388,11 @@ void checkTextNotEmptyOrWhitespace(const visualization_msgs::Marker& marker, std
   }
 }
 
-void checkTextEmpty(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkTextEmpty(const visualization_msgs::Marker& marker,
+                    std::stringstream& ss,
+                    ::ros::console::levels::Level& level)
 {
-  if(!marker.text.empty())
+  if (!marker.text.empty())
   {
     addSeparatorIfRequired(ss);
     ss << "Non-empty text is ignored.";
@@ -321,9 +400,11 @@ void checkTextEmpty(const visualization_msgs::Marker& marker, std::stringstream&
   }
 }
 
-void checkMesh(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkMesh(const visualization_msgs::Marker& marker,
+               std::stringstream& ss,
+               ::ros::console::levels::Level& level)
 {
-  if(marker.mesh_resource.empty())
+  if (marker.mesh_resource.empty())
   {
     addSeparatorIfRequired(ss);
     ss << "Empty mesh_resource path.";
@@ -331,7 +412,9 @@ void checkMesh(const visualization_msgs::Marker& marker, std::stringstream& ss,
   }
 }
 
-void checkMeshEmpty(const visualization_msgs::Marker& marker, std::stringstream& ss, ::ros::console::levels::Level& level)
+void checkMeshEmpty(const visualization_msgs::Marker& marker,
+                    std::stringstream& ss,
+                    ::ros::console::levels::Level& level)
 {
   if (!marker.mesh_resource.empty())
   {
@@ -347,18 +430,19 @@ void checkMeshEmpty(const visualization_msgs::Marker& marker, std::stringstream&
   }
 }
 
-}
+} // namespace
 
 bool checkMarkerMsg(const visualization_msgs::Marker& marker, MarkerDisplay* owner)
 {
-  if(marker.action != visualization_msgs::Marker::ADD)
+  if (marker.action != visualization_msgs::Marker::ADD)
     return true;
 
   std::stringstream ss;
   ::ros::console::levels::Level level = ::ros::console::levels::Debug;
   checkFloats(marker.pose.position, ss, level);
 
-  switch (marker.type) {
+  switch (marker.type)
+  {
   case visualization_msgs::Marker::ARROW:
     checkQuaternion(marker, ss, level);
     checkScale(marker, ss, level);
@@ -431,19 +515,21 @@ bool checkMarkerMsg(const visualization_msgs::Marker& marker, MarkerDisplay* own
     break;
 
   default:
-    ss << "Unknown marker type: " << marker.type << '.' ;
+    ss << "Unknown marker type: " << marker.type << '.';
     level = ::ros::console::levels::Error;
   }
 
-  if(ss.tellp() != 0) //stringstream is not empty
+  if (ss.tellp() != 0) // stringstream is not empty
   {
     std::string warning = ss.str();
 
     bool fatal = level >= ::ros::console::levels::Error;
     if (owner)
-      owner->setMarkerStatus(MarkerID(marker.ns, marker.id), fatal ? StatusProperty::Error : StatusProperty::Warn, warning);
+      owner->setMarkerStatus(MarkerID(marker.ns, marker.id),
+                             fatal ? StatusProperty::Error : StatusProperty::Warn, warning);
     else
-      ROS_LOG(level, ROSCONSOLE_DEFAULT_NAME ".marker", "Marker '%s/%d': %s", marker.ns.c_str(), marker.id, warning.c_str());
+      ROS_LOG(level, ROSCONSOLE_DEFAULT_NAME ".marker", "Marker '%s/%d': %s", marker.ns.c_str(),
+              marker.id, warning.c_str());
 
     return !fatal;
   }
@@ -461,33 +547,34 @@ bool checkMarkerArrayMsg(const visualization_msgs::MarkerArray& array, MarkerDis
   ::ros::console::levels::Level level = ::ros::console::levels::Debug;
   std::stringstream ss;
 
-  for(const visualization_msgs::Marker& marker : array.markers)
+  for (const visualization_msgs::Marker& marker : array.markers)
   {
     if (marker.action == visualization_msgs::Marker::DELETEALL)
     {
       if (!marker_ids.empty())
       {
-          addSeparatorIfRequired(ss);
-          ss << "DELETEALL after having markers added. These will never show.";
-          increaseLevel(::ros::console::levels::Warn, level);
+        addSeparatorIfRequired(ss);
+        ss << "DELETEALL after having markers added. These will never show.";
+        increaseLevel(::ros::console::levels::Warn, level);
       }
       marker_ids.clear();
       continue;
     }
 
     MarkerID current_id(marker.ns, marker.id);
-    std::vector<MarkerID>::iterator search = std::lower_bound(marker_ids.begin(), marker_ids.end(), current_id);
+    std::vector<MarkerID>::iterator search =
+        std::lower_bound(marker_ids.begin(), marker_ids.end(), current_id);
     if (search != marker_ids.end() && *search == current_id)
     {
       addSeparatorIfRequired(ss);
       increaseLevel(::ros::console::levels::Warn, level);
       if (marker.action == visualization_msgs::Marker::DELETE)
       {
-        ss << "Deleting just added marker '" <<  marker.ns.c_str() << "/" << marker.id << "'.";
+        ss << "Deleting just added marker '" << marker.ns.c_str() << "/" << marker.id << "'.";
         marker_ids.erase(search);
       }
       else
-        ss << "Adding marker '" <<  marker.ns.c_str() << "/" << marker.id << "' multiple times.";
+        ss << "Adding marker '" << marker.ns.c_str() << "/" << marker.id << "' multiple times.";
     }
     else
     {
@@ -495,7 +582,7 @@ bool checkMarkerArrayMsg(const visualization_msgs::MarkerArray& array, MarkerDis
     }
   }
 
-  if(ss.tellp() != 0) //stringstream is not empty
+  if (ss.tellp() != 0) // stringstream is not empty
   {
     std::string warning = ss.str();
 
