@@ -36,7 +36,7 @@
 namespace Ogre
 {
 class Any;
-}
+} // namespace Ogre
 
 namespace rviz
 {
