@@ -86,8 +86,7 @@ static float g_box_vertices[6 * 6 * 3] = {
 
     // bottom
     -0.5, -0.5, -0.5, -0.5, -0.5, 0.5, 0.5, -0.5, -0.5, 0.5, -0.5, -0.5, -0.5, -0.5, 0.5, 0.5, -0.5, 0.5,
-    // clang-format on
-};
+}; // clang-format on
 
 Ogre::String PointCloud::sm_Type = "PointCloud";
 
