@@ -35,8 +35,8 @@
 #include <QIcon>
 #include <QVariant>
 
-#include "rviz/config.h"
-#include "rviz/rviz_export.h"
+#include <rviz/config.h>
+#include <rviz/rviz_export.h>
 
 class QModelIndex;
 class QPainter;
@@ -44,7 +44,6 @@ class QStyleOptionViewItem;
 
 namespace rviz
 {
-
 class PropertyTreeModel;
 
 /** @brief A single element of a property tree, with a name, value,
@@ -63,12 +62,12 @@ class PropertyTreeModel;
  *       color_property_ = new ColorProperty( "Color", Qt::white,
  *                                            "Color to draw the range.",
  *                                            this, SLOT( updateColorAndAlpha() ));
- *     
+ *
  *       alpha_property_ = new FloatProperty( "Alpha", 0.5,
  *                                            "Amount of transparency to apply to the range.",
  *                                            this, SLOT( updateColorAndAlpha() ));
  *     }
- *     
+ *
  *     void RangeDisplay::updateColorAndAlpha()
  *     {
  *       Ogre::ColourValue oc = color_property_->getOgreColor();
@@ -98,14 +97,16 @@ class PropertyTreeModel;
  * To show a Property tree in a PropertyTreeWidget, wrap the root
  * Property in a PropertyTreeModel and call
  * PropertyTreeWidget::setModel() with it. */
-class RVIZ_EXPORT Property: public QObject
+class RVIZ_EXPORT Property : public QObject
 {
-Q_OBJECT
+  Q_OBJECT
 public:
   /** @brief Constructor.
    * @param name The name of this property.  Appears in the left column of a PropertyTreeWidget.
-   * @param default_value The initial value to store in the property.  Appears in the right column of a PropertyTreeWidget.
-   * @param description Text describing the property.  Is shown in the "help" area of a PropertyTreeWithHelp widget.
+   * @param default_value The initial value to store in the property.  Appears in the right column of a
+   * PropertyTreeWidget.
+   * @param description Text describing the property.  Is shown in the "help" area of a
+   * PropertyTreeWithHelp widget.
    * @param parent The parent Property, or NULL if there is no parent at this time.
    * @param changed_slot This should be a Qt slot specification,
    *        generated by Qt's @c SLOT() macro.  It should be a slot on
@@ -128,25 +129,26 @@ public:
    * specified, receiver is the one which gets connected.  If receiver
    * is not specified, parent is used instead.
    */
-  Property( const QString& name = QString(),
-            const QVariant default_value = QVariant(),
-            const QString& description = QString(),
-            Property* parent = 0,
-            const char *changed_slot = 0,
-            QObject* receiver = 0 );
+  Property(const QString& name = QString(),
+           const QVariant& default_value = QVariant(),
+           const QString& description = QString(),
+           Property* parent = nullptr,
+           const char* changed_slot = nullptr,
+           QObject* receiver = nullptr);
 
   /** @brief Destructor.  Removes this property from its parent's list
    * of children.
    */
-  virtual ~Property();
+  ~Property() override;
 
   /** @brief Remove and delete some or all child Properties.  Does not change
    * the value of this Property.
    * @param start_index The index of the first child to delete.
-   * @param count The number of children to delete, or -1 to delete from start_index to the end of the list.
+   * @param count The number of children to delete, or -1 to delete from start_index to the end of the
+   * list.
    *
    * Does not use numChildren() or takeChildAt(), operates directly on internal children_ list. */
-  virtual void removeChildren( int start_index = 0, int count = -1 );
+  virtual void removeChildren(int start_index = 0, int count = -1);
 
   /** @brief Set the new value for this property.  Returns true if the
    * new value is different from the old value, false if same.
@@ -159,7 +161,7 @@ public:
    * If the value set is an invalid QVariant (QVariant::isValid()
    * returns false), the value will not be editable in a
    * PropertyTreeWidget. */
-  virtual bool setValue( const QVariant& new_value );
+  virtual bool setValue(const QVariant& new_value);
 
   /** @brief Return the value of this Property as a QVariant.  If the
    * value has never been set, an invalid QVariant is returned. */
@@ -169,25 +171,34 @@ public:
    * @param name the new name.
    *
    * Internally, the name is stored with QObject::setObjectName(). */
-  virtual void setName( const QString& name );
+  virtual void setName(const QString& name);
 
   /** @brief Return the name of this Property as a QString. */
   virtual QString getName() const;
 
   /** @brief Return the name of this Property as a std::string. */
-  std::string getNameStd() const { return getName().toStdString(); }
+  std::string getNameStd() const
+  {
+    return getName().toStdString();
+  }
 
   /** @brief Set the description.
    * @param description the new description. */
-  virtual void setDescription( const QString& description );
+  virtual void setDescription(const QString& description);
 
   /** @brief Return the description. */
   virtual QString getDescription() const;
 
   /** @brief Set the icon to be displayed next to the property. */
-  virtual void setIcon( const QIcon& icon ) { icon_=icon; }
+  virtual void setIcon(const QIcon& icon)
+  {
+    icon_ = icon;
+  }
 
-  virtual QIcon getIcon() const { return icon_; }
+  virtual QIcon getIcon() const
+  {
+    return icon_;
+  }
 
   /** @brief Return the first child Property with the given name, or
    * the FailureProperty if no child has the name.
@@ -207,13 +218,16 @@ public:
    * message will be printed, but the program will not crash here.
    *
    * This is an Order(N) operation in the number of subproperties. */
-  virtual Property* subProp( const QString& sub_name );
+  virtual Property* subProp(const QString& sub_name);
 
   /** @brief Return the number of child objects (Property or otherwise).
    *
    * You can override this in a subclass to implement different child
    * storage. */
-  virtual int numChildren() const { return children_.size(); }
+  virtual int numChildren() const
+  {
+    return children_.size();
+  }
 
   /** @brief Return the child Property with the given index, or NULL
    * if the index is out of bounds or if the child at that index is
@@ -222,17 +236,17 @@ public:
    * This just checks the index against 0 and numChildren() and then
    * calls childAtUnchecked(), so it does not need to be overridden in
    * a subclass. */
-  Property* childAt( int index ) const;
+  Property* childAt(int index) const;
 
   /** @brief Return the child Property with the given index, without
    * checking whether the index is within bounds.
    *
    * You can override this in a subclass to implement different child
    * storage. */
-  virtual Property* childAtUnchecked( int index ) const;
+  virtual Property* childAtUnchecked(int index) const;
 
   /** @brief Return true if the list of children includes @a possible_child, false if not. */
-  bool contains( Property* possible_child ) const;
+  bool contains(Property* possible_child) const;
 
   /** @brief Return the parent Property. */
   Property* getParent() const;
@@ -243,7 +257,7 @@ public:
    * setParent() does not have any immediate side effects, like adding
    * itself to be a child of the parent.  It should only be used by
    * implementations of addChild() and takeChild() and such. */
-  void setParent( Property* new_parent );
+  void setParent(Property* new_parent);
 
   /** @brief Return data appropriate for the given column (0 or 1) and role for this Property.
    * @param column 0 for left column, 1 for right column.
@@ -257,34 +271,38 @@ public:
    * Return values from this function or overridden versions of it are
    * where background and foreground colors, check-box checked-state
    * values, text, and fonts all come from. */
-  virtual QVariant getViewData( int column, int role ) const;
+  virtual QVariant getViewData(int column, int role) const;
 
   /** @brief Return item flags appropriate for the given column (0 or
    * 1) for this Property.
    * @param column 0 for left column, 1 for right column.
-   * @return The Qt::ItemFlags for the given column of this property, including Qt::ItemIsSelectable, Qt::ItemIsEditable, etc. */
-  virtual Qt::ItemFlags getViewFlags( int column ) const;
+   * @return The Qt::ItemFlags for the given column of this property, including Qt::ItemIsSelectable,
+   * Qt::ItemIsEditable, etc. */
+  virtual Qt::ItemFlags getViewFlags(int column) const;
 
   /** @brief Hook to provide custom painting of the value data (right-hand column) in a subclass.
    * @param painter The QPainter to use.
-   * @param option A QStyleOptionViewItem with parameters of the paint job, like the rectangle, alignments, etc.
-   * @return true if painting has been done, false if not.  The default implementation always returns false.
+   * @param option A QStyleOptionViewItem with parameters of the paint job, like the rectangle,
+   * alignments, etc.
+   * @return true if painting has been done, false if not.  The default implementation always returns
+   * false.
    *
    * To implement a custom appearance of a Property value, override
    * this function to do the painting and return true.
    *
    * If this function returns false, a QStyledItemDelegate will do the painting. */
-  virtual bool paint( QPainter* painter, const QStyleOptionViewItem& option ) const
+  virtual bool paint(QPainter* painter, const QStyleOptionViewItem& option) const
   {
-    (void) painter;
-    (void) option;
+    (void)painter;
+    (void)option;
     return false;
   }
 
 
   /** @brief Create an editor widget to edit the value of this property.
    * @param parent The QWidget to set as the parent of the returned QWidget.
-   * @param option A QStyleOptionViewItem with parameters of the editor widget, like the rectangle, alignments, etc.
+   * @param option A QStyleOptionViewItem with parameters of the editor widget, like the rectangle,
+   * alignments, etc.
    *
    * @return the newly-created editor widget.  The default
    *         implementation creates a QSpinBox for integer values, a
@@ -298,13 +316,12 @@ public:
    * sets it with the results of PropertyTreeModel::data() after
    * creation, and after editing is finished it reads it and calls
    * PropertyTreeModel::setData() with the contents.  */
-  virtual QWidget* createEditor( QWidget* parent,
-                                 const QStyleOptionViewItem& option );
+  virtual QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option);
 
   /** @brief Returns true if @c this is an ancestor of
    * @a possible_child, meaning is the parent or parent of parent
    * etc. */
-  bool isAncestorOf( Property* possible_child ) const;
+  bool isAncestorOf(Property* possible_child) const;
 
   /** @brief Remove a given child object and return a pointer to it.
    * @return If child is contained here, it is returned; otherwise NULL.
@@ -314,26 +331,29 @@ public:
    * This uses only virtual functions, numChildren(),
    * childAtUnchecked(), and takeChildAt(), so it does not need to be
    * virtual itself. */
-  Property* takeChild( Property* child );
+  Property* takeChild(Property* child);
 
   /** @brief Take a child out of the child list, but don't destroy it.
    * @return Returns the child property at the given index, or NULL if the index is out of bounds.
    *
    * This notifies the model about the removal. */
-  virtual Property* takeChildAt( int index );
+  virtual Property* takeChildAt(int index);
 
   /** @brief Add a child property.
    * @param child The child property to add.
    * @param index [optional] The index at which to add the child.  If
    *   less than 0 or greater than the number of child properties, the
    *   child will be added at the end. */
-  virtual void addChild( Property* child, int index = -1 );
+  virtual void addChild(Property* child, int index = -1);
 
   /** @brief Set the model managing this Property and all its child properties, recursively. */
-  void setModel( PropertyTreeModel* model );
+  void setModel(PropertyTreeModel* model);
 
   /** @brief Return the model managing this Property and its childrent. */
-  PropertyTreeModel* getModel() const { return model_; }
+  PropertyTreeModel* getModel() const
+  {
+    return model_;
+  }
 
   /** @brief Return the row number of this property within its parent,
    * or -1 if it has no parent.
@@ -344,22 +364,29 @@ public:
   int rowNumberInParent() const;
 
   /** @brief Move the child at from_index to to_index. */
-  virtual void moveChild( int from_index, int to_index );
+  virtual void moveChild(int from_index, int to_index);
 
   /** @brief Load the value of this property and/or its children from
    * the given Config reference. */
-  virtual void load( const Config& config );
+  virtual void load(const Config& config);
 
   /** @brief Write the value of this property and/or its children into
    * the given Config reference. */
-  virtual void save( Config config ) const;
+  virtual void save(Config config) const;
 
-  /** @brief Returns true if the property is not read-only AND has data worth saving. */
-  bool shouldBeSaved() const { return !is_read_only_ && save_; }
+  /** @brief Returns true if the property has data worth saving. */
+  bool shouldBeSaved() const
+  {
+    return save_;
+  }
 
-  /** @brief If @a save is true and getReadOnly() is false,
-   * shouldBeSaved will return true; otherwise false.  Default is true. */
-  void setShouldBeSaved( bool save ) { save_ = save; }
+  /** @brief If @a save is false, neither the property nor its children will get saved.
+   * If true (the default), the property itself will only get saved if it is not read-only;
+   * children will get saved in any case (according to their save + read-only flags). */
+  void setShouldBeSaved(bool save)
+  {
+    save_ = save;
+  }
 
   /** @brief If true, the children of this property should set their
    *         ItemIsEnabled flag to false */
@@ -369,24 +396,33 @@ public:
    *
    * This is a convenience function which calls setHidden( true ).
    * @sa show(), setHidden(), getHidden() */
-  void hide() { setHidden( true ); }
+  void hide()
+  {
+    setHidden(true);
+  }
 
   /** @brief Show this Property in any PropertyTreeWidgets.
    *
    * This is a convenience function which calls setHidden( false ).
    * @sa show(), setHidden(), getHidden() */
-  void show() { setHidden( false ); }
+  void show()
+  {
+    setHidden(false);
+  }
 
   /** @brief Hide or show this property in any PropertyTreeWidget
    * viewing its parent.
    *
    * The hidden/shown state is not saved or loaded, it is expected to
    * be managed by the owner of the property. */
-  virtual void setHidden( bool hidden );
+  virtual void setHidden(bool hidden);
 
   /** @brief Return the hidden/shown state.  True means hidden, false
    * means visible. */
-  virtual bool getHidden() const { return hidden_; }
+  virtual bool getHidden() const
+  {
+    return hidden_;
+  }
 
   /** @brief Prevent or allow users to edit this property from a PropertyTreeWidget.
    *
@@ -395,11 +431,17 @@ public:
    * This is not inherently recursive.  Parents which need this to
    * propagate to their children must override this to implement
    * that. */
-  virtual void setReadOnly( bool read_only ) { is_read_only_ = read_only; }
+  virtual void setReadOnly(bool read_only)
+  {
+    is_read_only_ = read_only;
+  }
 
   /** @brief Return the read-only-ness of this property.
    * @sa setReadOnly() */
-  virtual bool getReadOnly() { return is_read_only_; }
+  virtual bool getReadOnly() const
+  {
+    return is_read_only_;
+  }
 
   /** @brief Collapse (hide the children of) this Property.
    *
@@ -425,14 +467,14 @@ Q_SIGNALS:
   void changed();
 
   /** @brief Emitted after insertions and deletions of child Properties. */
-  void childListChanged( Property* this_property );
+  void childListChanged(Property* this_property);
 
 protected:
   /** @brief Load the value of this property specifically, not including children.
    *
    * This handles value_ types of string, double/float, bool, and int.
    * If config is invalid, this does nothing. */
-  void loadValue( const Config& config );
+  void loadValue(const Config& config);
 
   /** @brief This is the central property value.  If you set it
    * directly in a subclass, do so with care because many things
