@@ -30,14 +30,14 @@
 #include "robot.h"
 #include "robot_link.h"
 #include "robot_joint.h"
-#include "properties/property.h"
-#include "properties/enum_property.h"
-#include "properties/bool_property.h"
-#include "display_context.h"
+#include <rviz/properties/property.h>
+#include <rviz/properties/enum_property.h>
+#include <rviz/properties/bool_property.h>
+#include <rviz/display_context.h>
 
-#include "ogre_helpers/object.h"
-#include "ogre_helpers/shape.h"
-#include "ogre_helpers/axes.h"
+#include <rviz/ogre_helpers/object.h>
+#include <rviz/ogre_helpers/shape.h>
+#include <rviz/ogre_helpers/axes.h>
 
 #include <urdf_model/model.h>
 
@@ -53,17 +53,19 @@
 
 namespace rviz
 {
-
-Robot::Robot( Ogre::SceneNode* root_node, DisplayContext* context, const std::string& name, Property* parent_property )
-  : scene_manager_( context->getSceneManager() )
-  , visible_( true )
-  , visual_visible_( true )
-  , collision_visible_( false )
-  , context_( context )
-  , doing_set_checkbox_( false )
-  , robot_loaded_( false )
-  , inChangedEnableAllLinks( false )
-  , name_( name )
+Robot::Robot(Ogre::SceneNode* root_node,
+             DisplayContext* context,
+             const std::string& name,
+             Property* parent_property)
+  : scene_manager_(context->getSceneManager())
+  , visible_(true)
+  , visual_visible_(true)
+  , collision_visible_(false)
+  , context_(context)
+  , doing_set_checkbox_(false)
+  , robot_loaded_(false)
+  , inChangedEnableAllLinks(false)
+  , name_(name)
 {
   root_visual_node_ = root_node->createChildSceneNode();
   root_collision_node_ = root_node->createChildSceneNode();
@@ -71,63 +73,42 @@ Robot::Robot( Ogre::SceneNode* root_node, DisplayContext* context, const std::st
 
   link_factory_ = new LinkFactory();
 
-  setVisualVisible( visual_visible_ );
-  setCollisionVisible( collision_visible_ );
+  setVisualVisible(visual_visible_);
+  setCollisionVisible(collision_visible_);
   setAlpha(1.0f);
 
-  link_tree_ = new Property( "Links", QVariant(), "", parent_property );
+  link_tree_ = new Property("Links", QVariant(), "", parent_property);
   link_tree_->hide(); // hide until loaded
 
-  link_tree_style_ = new EnumProperty(
-                            "Link Tree Style",
-                            "",
-                            "How the list of links is displayed",
-                            link_tree_,
-                            SLOT( changedLinkTreeStyle() ),
-                            this );
+  link_tree_style_ = new EnumProperty("Link Tree Style", "", "How the list of links is displayed",
+                                      link_tree_, SLOT(changedLinkTreeStyle()), this);
   initLinkTreeStyle();
-  expand_tree_= new BoolProperty(
-                            "Expand Tree",
-                            false,
-                            "Expand or collapse link tree",
-                            link_tree_,
-                            SLOT( changedExpandTree() ),
-                            this );
-  expand_link_details_ = new BoolProperty(
-                            "Expand Link Details",
-                            false,
-                            "Expand link details (sub properties) to see all info for all links.",
-                            link_tree_,
-                            SLOT( changedExpandLinkDetails() ),
-                            this );
-  expand_joint_details_ = new BoolProperty(
-                            "Expand Joint Details",
-                            false,
-                            "Expand joint details (sub properties) to see all info for all joints.",
-                            link_tree_,
-                            SLOT( changedExpandJointDetails() ),
-                            this );
-  enable_all_links_ = new BoolProperty(
-                            "All Links Enabled",
-                            true,
-                            "Turn all links on or off.",
-                            link_tree_,
-                            SLOT( changedEnableAllLinks() ),
-                            this );
+  expand_tree_ = new BoolProperty("Expand Tree", false, "Expand or collapse link tree", link_tree_,
+                                  SLOT(changedExpandTree()), this);
+  expand_link_details_ =
+      new BoolProperty("Expand Link Details", false,
+                       "Expand link details (sub properties) to see all info for all links.", link_tree_,
+                       SLOT(changedExpandLinkDetails()), this);
+  expand_joint_details_ =
+      new BoolProperty("Expand Joint Details", false,
+                       "Expand joint details (sub properties) to see all info for all joints.",
+                       link_tree_, SLOT(changedExpandJointDetails()), this);
+  enable_all_links_ = new BoolProperty("All Links Enabled", true, "Turn all links on or off.",
+                                       link_tree_, SLOT(changedEnableAllLinks()), this);
 }
 
 Robot::~Robot()
 {
   clear();
 
-  scene_manager_->destroySceneNode( root_visual_node_->getName() );
-  scene_manager_->destroySceneNode( root_collision_node_->getName() );
-  scene_manager_->destroySceneNode( root_other_node_->getName() );
+  scene_manager_->destroySceneNode(root_visual_node_);
+  scene_manager_->destroySceneNode(root_collision_node_);
+  scene_manager_->destroySceneNode(root_other_node_);
   delete link_factory_;
   delete link_tree_;
 }
 
-void Robot::setLinkFactory(LinkFactory *link_factory)
+void Robot::setLinkFactory(LinkFactory* link_factory)
 {
   if (link_factory)
   {
@@ -136,30 +117,30 @@ void Robot::setLinkFactory(LinkFactory *link_factory)
   }
 }
 
-void Robot::setVisible( bool visible )
+void Robot::setVisible(bool visible)
 {
   visible_ = visible;
-  if ( visible )
+  if (visible)
   {
-    root_visual_node_->setVisible( visual_visible_ );
-    root_collision_node_->setVisible( collision_visible_ );
+    root_visual_node_->setVisible(visual_visible_);
+    root_collision_node_->setVisible(collision_visible_);
     updateLinkVisibilities();
   }
   else
   {
-    root_visual_node_->setVisible( false );
-    root_collision_node_->setVisible( false );
+    root_visual_node_->setVisible(false);
+    root_collision_node_->setVisible(false);
     updateLinkVisibilities();
   }
 }
 
-void Robot::setVisualVisible( bool visible )
+void Robot::setVisualVisible(bool visible)
 {
   visual_visible_ = visible;
   updateLinkVisibilities();
 }
 
-void Robot::setCollisionVisible( bool visible )
+void Robot::setCollisionVisible(bool visible)
 {
   collision_visible_ = visible;
   updateLinkVisibilities();
@@ -169,7 +150,7 @@ void Robot::updateLinkVisibilities()
 {
   M_NameToLink::iterator it = links_.begin();
   M_NameToLink::iterator end = links_.end();
-  for ( ; it != end; ++it )
+  for (; it != end; ++it)
   {
     RobotLink* link = it->second;
     link->updateVisibility();
@@ -197,7 +178,7 @@ void Robot::setAlpha(float a)
 
   M_NameToLink::iterator it = links_.begin();
   M_NameToLink::iterator end = links_.end();
-  for ( ; it != end; ++it )
+  for (; it != end; ++it)
   {
     RobotLink* link = it->second;
 
@@ -214,7 +195,7 @@ void Robot::clear()
 
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     RobotLink* link = link_it->second;
     delete link;
@@ -222,7 +203,7 @@ void Robot::clear()
 
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     RobotJoint* joint = joint_it->second;
     delete joint;
@@ -235,24 +216,21 @@ void Robot::clear()
   root_other_node_->removeAndDestroyAllChildren();
 }
 
-RobotLink* Robot::LinkFactory::createLink(
-    Robot* robot,
-    const urdf::LinkConstSharedPtr& link,
-    const std::string& parent_joint_name,
-    bool visual,
-    bool collision)
+RobotLink* Robot::LinkFactory::createLink(Robot* robot,
+                                          const urdf::LinkConstSharedPtr& link,
+                                          const std::string& parent_joint_name,
+                                          bool visual,
+                                          bool collision)
 {
   return new RobotLink(robot, link, parent_joint_name, visual, collision);
 }
 
-RobotJoint* Robot::LinkFactory::createJoint(
-    Robot* robot,
-    const urdf::JointConstSharedPtr& joint)
+RobotJoint* Robot::LinkFactory::createJoint(Robot* robot, const urdf::JointConstSharedPtr& joint)
 {
   return new RobotJoint(robot, joint);
 }
 
-void Robot::load( const urdf::ModelInterface &urdf, bool visual, bool collision )
+void Robot::load(const urdf::ModelInterface& urdf, bool visual, bool collision)
 {
   link_tree_->hide(); // hide until loaded
   robot_loaded_ = false;
@@ -261,15 +239,15 @@ void Robot::load( const urdf::ModelInterface &urdf, bool visual, bool collision
   clear();
 
   // the root link is discovered below.  Set to NULL until found.
-  root_link_ = NULL;
+  root_link_ = nullptr;
 
   // Create properties for each link.
   // Properties are not added to display until changedLinkTreeStyle() is called (below).
   {
-    typedef std::map<std::string, urdf::LinkSharedPtr > M_NameToUrdfLink;
+    typedef std::map<std::string, urdf::LinkSharedPtr> M_NameToUrdfLink;
     M_NameToUrdfLink::const_iterator link_it = urdf.links_.begin();
     M_NameToUrdfLink::const_iterator link_end = urdf.links_.end();
-    for( ; link_it != link_end; ++link_it )
+    for (; link_it != link_end; ++link_it)
     {
       const urdf::LinkConstSharedPtr& urdf_link = link_it->second;
       std::string parent_joint_name;
@@ -278,12 +256,8 @@ void Robot::load( const urdf::ModelInterface &urdf, bool visual, bool collision
       {
         parent_joint_name = urdf_link->parent_joint->name;
       }
-      
-      RobotLink* link = link_factory_->createLink( this,
-                                                   urdf_link,
-                                                   parent_joint_name,
-                                                   visual,
-                                                   collision );
+
+      RobotLink* link = link_factory_->createLink(this, urdf_link, parent_joint_name, visual, collision);
 
       if (urdf_link == urdf.getRoot())
       {
@@ -292,24 +266,24 @@ void Robot::load( const urdf::ModelInterface &urdf, bool visual, bool collision
 
       links_[urdf_link->name] = link;
 
-      link->setRobotAlpha( alpha_ );
+      link->setRobotAlpha(alpha_);
     }
   }
 
   // Create properties for each joint.
   // Properties are not added to display until changedLinkTreeStyle() is called (below).
   {
-    typedef std::map<std::string, urdf::JointSharedPtr > M_NameToUrdfJoint;
+    typedef std::map<std::string, urdf::JointSharedPtr> M_NameToUrdfJoint;
     M_NameToUrdfJoint::const_iterator joint_it = urdf.joints_.begin();
     M_NameToUrdfJoint::const_iterator joint_end = urdf.joints_.end();
-    for( ; joint_it != joint_end; ++joint_it )
+    for (; joint_it != joint_end; ++joint_it)
     {
       const urdf::JointConstSharedPtr& urdf_joint = joint_it->second;
-      RobotJoint* joint = link_factory_->createJoint( this, urdf_joint );
+      RobotJoint* joint = link_factory_->createJoint(this, urdf_joint);
 
       joints_[urdf_joint->name] = joint;
 
-      joint->setRobotAlpha( alpha_ );
+      joint->setRobotAlpha(alpha_);
     }
   }
 
@@ -324,8 +298,8 @@ void Robot::load( const urdf::ModelInterface &urdf, bool visual, bool collision
   // at startup the link tree is collapsed since it is large and not often needed.
   link_tree_->collapse();
 
-  setVisualVisible( isVisualVisible() );
-  setCollisionVisible( isCollisionVisible() );
+  setVisualVisible(isVisualVisible());
+  setCollisionVisible(isCollisionVisible());
 }
 
 void Robot::unparentLinkProperties()
@@ -333,17 +307,17 @@ void Robot::unparentLinkProperties()
   // remove link properties from their parents
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
-    link_it->second->setParentProperty(NULL);
+    link_it->second->setParentProperty(nullptr);
   }
 
   // remove joint properties from their parents
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
-    joint_it->second->setParentProperty(NULL);
+    joint_it->second->setParentProperty(nullptr);
   }
 }
 
@@ -352,7 +326,7 @@ void Robot::useDetailProperty(bool use_detail)
   // remove sub properties and add them to detail
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     link_it->second->useDetailProperty(use_detail);
   }
@@ -360,7 +334,7 @@ void Robot::useDetailProperty(bool use_detail)
   // remove joint properties from their parents
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     joint_it->second->useDetailProperty(use_detail);
   }
@@ -372,7 +346,7 @@ void Robot::changedExpandTree()
 
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     if (expand)
       link_it->second->getLinkProperty()->expand();
@@ -382,7 +356,7 @@ void Robot::changedExpandTree()
 
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     if (expand)
       joint_it->second->getJointProperty()->expand();
@@ -397,14 +371,14 @@ void Robot::changedHideSubProperties()
 
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     link_it->second->hideSubProperties(hide);
   }
 
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     joint_it->second->hideSubProperties(hide);
   }
@@ -416,7 +390,7 @@ void Robot::changedExpandLinkDetails()
 
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     link_it->second->expandDetails(expand);
   }
@@ -428,7 +402,7 @@ void Robot::changedExpandJointDetails()
 
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     joint_it->second->expandDetails(expand);
   }
@@ -445,7 +419,7 @@ void Robot::changedEnableAllLinks()
 
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end ; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     if (link_it->second->hasGeometry())
     {
@@ -455,7 +429,7 @@ void Robot::changedEnableAllLinks()
 
   M_NameToJoint::iterator joint_it = joints_.begin();
   M_NameToJoint::iterator joint_end = joints_.end();
-  for ( ; joint_it != joint_end ; ++joint_it )
+  for (; joint_it != joint_end; ++joint_it)
   {
     if (joint_it->second->hasDescendentLinksWithGeometry())
     {
@@ -466,7 +440,7 @@ void Robot::changedEnableAllLinks()
   inChangedEnableAllLinks = false;
 }
 
-void Robot::setEnableAllLinksCheckbox(QVariant val)
+void Robot::setEnableAllLinksCheckbox(const QVariant& val)
 {
   // doing_set_checkbox_ prevents changedEnableAllLinks from turning all
   // links off when we modify the enable_all_links_ property.
@@ -478,40 +452,33 @@ void Robot::setEnableAllLinksCheckbox(QVariant val)
 void Robot::initLinkTreeStyle()
 {
   style_name_map_.clear();
-	style_name_map_[STYLE_LINK_LIST] = "Links in Alphabetic Order";
-	style_name_map_[STYLE_JOINT_LIST] = "Joints in Alphabetic Order";
-	style_name_map_[STYLE_LINK_TREE] = "Tree of links";
-	style_name_map_[STYLE_JOINT_LINK_TREE] = "Tree of links and joints";
+  style_name_map_[STYLE_LINK_LIST] = "Links in Alphabetic Order";
+  style_name_map_[STYLE_JOINT_LIST] = "Joints in Alphabetic Order";
+  style_name_map_[STYLE_LINK_TREE] = "Tree of links";
+  style_name_map_[STYLE_JOINT_LINK_TREE] = "Tree of links and joints";
 
   link_tree_style_->clearOptions();
   std::map<LinkTreeStyle, std::string>::const_iterator style_it = style_name_map_.begin();
   std::map<LinkTreeStyle, std::string>::const_iterator style_end = style_name_map_.end();
-  for ( ; style_it != style_end ; ++style_it )
+  for (; style_it != style_end; ++style_it)
   {
-    link_tree_style_->addOptionStd( style_it->second, style_it->first );
+    link_tree_style_->addOptionStd(style_it->second, style_it->first);
   }
 }
 
 bool Robot::styleShowLink(LinkTreeStyle style)
 {
-  return 
-    style == STYLE_LINK_LIST ||
-    style == STYLE_LINK_TREE ||
-    style == STYLE_JOINT_LINK_TREE;
+  return style == STYLE_LINK_LIST || style == STYLE_LINK_TREE || style == STYLE_JOINT_LINK_TREE;
 }
 
 bool Robot::styleShowJoint(LinkTreeStyle style)
 {
-  return 
-    style == STYLE_JOINT_LIST ||
-    style == STYLE_JOINT_LINK_TREE;
+  return style == STYLE_JOINT_LIST || style == STYLE_JOINT_LINK_TREE;
 }
 
 bool Robot::styleIsTree(LinkTreeStyle style)
 {
-  return 
-    style == STYLE_LINK_TREE ||
-    style == STYLE_JOINT_LINK_TREE;
+  return style == STYLE_LINK_TREE || style == STYLE_JOINT_LINK_TREE;
 }
 
 void Robot::setLinkTreeStyle(LinkTreeStyle style)
@@ -533,7 +500,7 @@ void Robot::changedLinkTreeStyle()
 
   unparentLinkProperties();
 
-  //expand_tree_->setValue(false);
+  // expand_tree_->setValue(false);
 
   switch (style)
   {
@@ -551,7 +518,7 @@ void Robot::changedLinkTreeStyle()
     useDetailProperty(false);
     M_NameToJoint::iterator joint_it = joints_.begin();
     M_NameToJoint::iterator joint_end = joints_.end();
-    for ( ; joint_it != joint_end ; ++joint_it )
+    for (; joint_it != joint_end; ++joint_it)
     {
       joint_it->second->setParentProperty(link_tree_);
       joint_it->second->setJointPropertyDescription();
@@ -564,7 +531,7 @@ void Robot::changedLinkTreeStyle()
     useDetailProperty(false);
     M_NameToLink::iterator link_it = links_.begin();
     M_NameToLink::iterator link_end = links_.end();
-    for ( ; link_it != link_end ; ++link_it )
+    for (; link_it != link_end; ++link_it)
     {
       link_it->second->setParentProperty(link_tree_);
     }
@@ -575,14 +542,16 @@ void Robot::changedLinkTreeStyle()
   {
   case STYLE_LINK_TREE:
     link_tree_->setName("Link Tree");
-    link_tree_->setDescription("A tree of all links in the robot.  Uncheck a link to hide its geometry.");
+    link_tree_->setDescription(
+        "A tree of all links in the robot.  Uncheck a link to hide its geometry.");
     expand_tree_->show();
     expand_link_details_->show();
     expand_joint_details_->hide();
     break;
   case STYLE_JOINT_LINK_TREE:
     link_tree_->setName("Link/Joint Tree");
-    link_tree_->setDescription("A tree of all joints and links in the robot.  Uncheck a link to hide its geometry.");
+    link_tree_->setDescription(
+        "A tree of all joints and links in the robot.  Uncheck a link to hide its geometry.");
     expand_tree_->show();
     expand_link_details_->show();
     expand_joint_details_->show();
@@ -597,7 +566,8 @@ void Robot::changedLinkTreeStyle()
   case STYLE_LINK_LIST:
   default:
     link_tree_->setName("Links");
-    link_tree_->setDescription("All links in the robot in alphabetic order.  Uncheck a link to hide its geometry.");
+    link_tree_->setDescription(
+        "All links in the robot in alphabetic order.  Uncheck a link to hide its geometry.");
     expand_tree_->hide();
     expand_link_details_->show();
     expand_joint_details_->hide();
@@ -612,7 +582,7 @@ void Robot::changedLinkTreeStyle()
 
 
 // recursive helper for setLinkTreeStyle() when style is *_TREE
-void Robot::addLinkToLinkTree(LinkTreeStyle style, Property *parent, RobotLink *link)
+void Robot::addLinkToLinkTree(LinkTreeStyle style, Property* parent, RobotLink* link)
 {
   if (styleShowLink(style))
   {
@@ -622,9 +592,9 @@ void Robot::addLinkToLinkTree(LinkTreeStyle style, Property *parent, RobotLink *
 
   std::vector<std::string>::const_iterator child_joint_it = link->getChildJointNames().begin();
   std::vector<std::string>::const_iterator child_joint_end = link->getChildJointNames().end();
-  for ( ; child_joint_it != child_joint_end ; ++child_joint_it )
+  for (; child_joint_it != child_joint_end; ++child_joint_it)
   {
-    RobotJoint* child_joint = getJoint( *child_joint_it );
+    RobotJoint* child_joint = getJoint(*child_joint_it);
     if (child_joint)
     {
       addJointToLinkTree(style, parent, child_joint);
@@ -633,7 +603,7 @@ void Robot::addLinkToLinkTree(LinkTreeStyle style, Property *parent, RobotLink *
 }
 
 // recursive helper for setLinkTreeStyle() when style is *_TREE
-void Robot::addJointToLinkTree(LinkTreeStyle style, Property *parent, RobotJoint *joint)
+void Robot::addJointToLinkTree(LinkTreeStyle style, Property* parent, RobotJoint* joint)
 {
   if (styleShowJoint(style))
   {
@@ -642,32 +612,32 @@ void Robot::addJointToLinkTree(LinkTreeStyle style, Property *parent, RobotJoint
     joint->setJointPropertyDescription();
   }
 
-  RobotLink *link = getLink( joint->getChildLinkName() );
+  RobotLink* link = getLink(joint->getChildLinkName());
   if (link)
   {
     addLinkToLinkTree(style, parent, link);
   }
 }
 
-RobotLink* Robot::getLink( const std::string& name )
+RobotLink* Robot::getLink(const std::string& name)
 {
-  M_NameToLink::iterator it = links_.find( name );
-  if ( it == links_.end() )
+  M_NameToLink::iterator it = links_.find(name);
+  if (it == links_.end())
   {
-    ROS_WARN( "Link [%s] does not exist", name.c_str() );
-    return NULL;
+    ROS_WARN("Link [%s] does not exist", name.c_str());
+    return nullptr;
   }
 
   return it->second;
 }
 
-RobotJoint* Robot::getJoint( const std::string& name )
+RobotJoint* Robot::getJoint(const std::string& name)
 {
-  M_NameToJoint::iterator it = joints_.find( name );
-  if ( it == joints_.end() )
+  M_NameToJoint::iterator it = joints_.find(name);
+  if (it == joints_.end())
   {
-    ROS_WARN( "Joint [%s] does not exist", name.c_str() );
-    return NULL;
+    ROS_WARN("Joint [%s] does not exist", name.c_str());
+    return nullptr;
   }
 
   return it->second;
@@ -682,9 +652,9 @@ void Robot::calculateJointCheckboxes()
   int links_with_geom_unchecked = 0;
 
   // check root link
-  RobotLink *link = root_link_;
+  RobotLink* link = root_link_;
 
-  if(!link)
+  if (!link)
   {
     setEnableAllLinksCheckbox(QVariant());
     return;
@@ -701,15 +671,16 @@ void Robot::calculateJointCheckboxes()
   // check all child links and joints recursively
   std::vector<std::string>::const_iterator child_joint_it = link->getChildJointNames().begin();
   std::vector<std::string>::const_iterator child_joint_end = link->getChildJointNames().end();
-  for ( ; child_joint_it != child_joint_end ; ++child_joint_it )
+  for (; child_joint_it != child_joint_end; ++child_joint_it)
   {
-    RobotJoint* child_joint = getJoint( *child_joint_it );
+    RobotJoint* child_joint = getJoint(*child_joint_it);
     if (child_joint)
     {
       int child_links_with_geom;
       int child_links_with_geom_checked;
       int child_links_with_geom_unchecked;
-      child_joint->calculateJointCheckboxesRecursive(child_links_with_geom, child_links_with_geom_checked, child_links_with_geom_unchecked);
+      child_joint->calculateJointCheckboxesRecursive(
+          child_links_with_geom, child_links_with_geom_checked, child_links_with_geom_unchecked);
       links_with_geom_checked += child_links_with_geom_checked;
       links_with_geom_unchecked += child_links_with_geom_unchecked;
     }
@@ -730,7 +701,7 @@ void Robot::update(const LinkUpdater& updater)
 {
   M_NameToLink::iterator link_it = links_.begin();
   M_NameToLink::iterator link_end = links_.end();
-  for ( ; link_it != link_end; ++link_it )
+  for (; link_it != link_end; ++link_it)
   {
     RobotLink* link = link_it->second;
 
@@ -738,55 +709,50 @@ void Robot::update(const LinkUpdater& updater)
 
     Ogre::Vector3 visual_position, collision_position;
     Ogre::Quaternion visual_orientation, collision_orientation;
-    if( updater.getLinkTransforms( link->getName(),
-                                   visual_position, visual_orientation,
-                                   collision_position, collision_orientation
-                                   ))
+    if (updater.getLinkTransforms(link->getName(), visual_position, visual_orientation,
+                                  collision_position, collision_orientation))
     {
-      // Check if visual_orientation, visual_position, collision_orientation, and collision_position are NaN.
+      // Check if visual_orientation, visual_position, collision_orientation, and collision_position are
+      // NaN.
       if (visual_orientation.isNaN())
       {
-        ROS_ERROR_THROTTLE(
-          1.0,
-          "visual orientation of %s contains NaNs. Skipping render as long as the orientation is invalid.",
-          link->getName().c_str()
-        );
+        ROS_ERROR_THROTTLE(1.0,
+                           "visual orientation of %s contains NaNs. "
+                           "Skipping render as long as the orientation is invalid.",
+                           link->getName().c_str());
         continue;
       }
       if (visual_position.isNaN())
       {
         ROS_ERROR_THROTTLE(
-          1.0,
-          "visual position of %s contains NaNs. Skipping render as long as the position is invalid.",
-          link->getName().c_str()
-        );
+            1.0,
+            "visual position of %s contains NaNs. Skipping render as long as the position is invalid.",
+            link->getName().c_str());
         continue;
       }
       if (collision_orientation.isNaN())
       {
-        ROS_ERROR_THROTTLE(
-          1.0,
-          "collision orientation of %s contains NaNs. Skipping render as long as the orientation is invalid.",
-          link->getName().c_str()
-        );
+        ROS_ERROR_THROTTLE(1.0,
+                           "collision orientation of %s contains NaNs. "
+                           "Skipping render as long as the orientation is invalid.",
+                           link->getName().c_str());
         continue;
       }
       if (collision_position.isNaN())
       {
-        ROS_ERROR_THROTTLE(
-          1.0,
-          "collision position of %s contains NaNs. Skipping render as long as the position is invalid.",
-          link->getName().c_str()
-        );
+        ROS_ERROR_THROTTLE(1.0,
+                           "collision position of %s contains NaNs. "
+                           "Skipping render as long as the position is invalid.",
+                           link->getName().c_str());
         continue;
       }
-      link->setTransforms( visual_position, visual_orientation, collision_position, collision_orientation );
+      link->setTransforms(visual_position, visual_orientation, collision_position, collision_orientation);
 
       std::vector<std::string>::const_iterator joint_it = link->getChildJointNames().begin();
       std::vector<std::string>::const_iterator joint_end = link->getChildJointNames().end();
-      for ( ; joint_it != joint_end ; ++joint_it )
+      for (; joint_it != joint_end; ++joint_it)
       {
-        RobotJoint *joint = getJoint(*joint_it);
+        RobotJoint* joint = getJoint(*joint_it);
         if (joint)
         {
           joint->setTransforms(visual_position, visual_orientation);
@@ -800,22 +766,22 @@ void Robot::update(const LinkUpdater& updater)
   }
 }
 
-void Robot::setPosition( const Ogre::Vector3& position )
+void Robot::setPosition(const Ogre::Vector3& position)
 {
-  root_visual_node_->setPosition( position );
-  root_collision_node_->setPosition( position );
+  root_visual_node_->setPosition(position);
+  root_collision_node_->setPosition(position);
 }
 
-void Robot::setOrientation( const Ogre::Quaternion& orientation )
+void Robot::setOrientation(const Ogre::Quaternion& orientation)
 {
-  root_visual_node_->setOrientation( orientation );
-  root_collision_node_->setOrientation( orientation );
+  root_visual_node_->setOrientation(orientation);
+  root_collision_node_->setOrientation(orientation);
 }
 
-void Robot::setScale( const Ogre::Vector3& scale )
+void Robot::setScale(const Ogre::Vector3& scale)
 {
-  root_visual_node_->setScale( scale );
-  root_collision_node_->setScale( scale );
+  root_visual_node_->setScale(scale);
+  root_collision_node_->setScale(scale);
 }
 
 const Ogre::Vector3& Robot::getPosition()
